@@ -24,16 +24,16 @@ def timethis(fn=None, *, logger=None):
     return callable(fn) and inner(fn) or inner
 
 
-def with_log(fn=None, *, logger=None, is_debug=True):
+def with_log(fn=None, *, logger=None, is_debug=False):
     """打印日志"""
 
     def inner(f):
         @functools.wraps(f)
         def _inner(*args, **kwargs):
-            is_debug and logger.debug(
+            logger.debug(
                 f'func({f.__name__}) running(args={args}, kwargs={kwargs})')
-            result = r(f)(*args, **kwargs)
-            is_debug and logger.debug(f'func({f.__name__}) result: {result}')
+            result = r(f, is_debug=is_debug)(*args, **kwargs)
+            logger.debug(f'func({f.__name__}) result: {result}')
             return result
 
         return _inner
